{% extends 'assets/base.html' %} {% load url from future %} {% load icons %} {% load bob %} {% block content %}

### History Assets

{% if status %} {% icon 'fugue-user-silhouette' %} Show all changes. {% else %} {% icon 'fugue-user-silhouette-question' %} Show only status changes. {% endif %}

Date | Author | Field | Before | After
--- | --- | --- | --- | ---
{% for h in history_page.object_list %}
{{ h.date|timesince_limited }} | {{ h.user|default:'' }} | {{ h.field_name }} | {{ h.old_value }} | {{ h.new_value }}
{% endfor %}

{% pagination history_page fugue_icons=1 show_all=1 url_query=url_query query_variable_name=query_variable_name %} {% endblock content %}